<?php

/**
 * @file
 * Drush commands.
 */

/**
 * Implements hook_drush_command().
 */
function mask_user_data_drush_command() {
  $items = array();

  $items['mask_user_data'] = array(
    'description' => dt('Masks user data in the database.'),
    'aliases' => array('mud'),
    'arguments' => array(
      'uid' => 'User Id of the user to mask.',
    ),
    'examples' => array(
      'drush mud' => 'Masks users data in the database.',
      'drush mud 1' => 'Masks a particular user data in the database.',
    ),
  );

  return $items;
}

/**
 * Drush callback to mask user data.
 *
 * @param int $uid
 *   User ID. If none given then all users will be masked.
 */
function drush_mask_user_data($uid = NULL) {
  $enabled = variable_get('mask_user_data_enabled', FALSE);
  if ($enabled) {
    drush_log(dt('Data masking is enabled.'), 'success');

    $already_masked = variable_get('mask_user_data_already_masked', FALSE);
    if ($already_masked) {
      drush_log(dt('The user data has already been masked.'), 'success');
    }
    else {
      if (drush_confirm('Are you sure you want to mask user data?')) {
        $map_array = variable_get('mask_user_data_map_array', NULL);
        if (empty($map_array) || !is_array($map_array)) {
          drush_log(dt('Invalid or empty map array. Please check the configuration.'), 'error');
        }
        else {
          if (!is_null($uid)) {
            if (user_load($uid)) {
              mask_user_data_mask_user($uid, $map_array);
              drush_log(dt('User UID=' . $uid . ' was masked.'), 'success');
            }
            else {
              drush_log(dt('User UID=' . $uid . ' does not exists.'), 'error');
            }
          }
          else {
            mask_user_data_setup_batch();
          }
        }
      }
      else {
        drush_user_abort();
      }
    }
  }
  else {
    drush_log(dt('Data masking is disabled.'), 'success');
  }
}
